"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_plugins_1 = require("@expo/config-plugins");
const withSSLPinning = (config, props) => {
    config = (0, config_plugins_1.withInfoPlist)(config, (config) => {
        const infoPlist = config.modResults;
        if (!props) {
            delete infoPlist.TSKConfiguration;
            return config;
        }
        const domainsConfig = Object.fromEntries(Object.entries(props).map(([hostName, certificates]) => {
            return [
                hostName,
                {
                    TSKEnforcePinning: true,
                    TSKIncludeSubdomains: true,
                    TSKPublicKeyHashes: certificates,
                },
            ];
        }));
        infoPlist.TSKConfiguration = {
            TSKSwizzleNetworkDelegates: true, // auto-setup on startup
            TSKPinnedDomains: domainsConfig,
        };
        // TODO: warn when overriding?
        return config;
    });
    config = (0, config_plugins_1.withGradleProperties)(config, (config) => {
        const gradleProperties = config.modResults;
        const existingIndex = gradleProperties.findIndex((prop) => prop.type === "property" && prop.key === "RNAS_PINNING_CONFIG");
        if (existingIndex !== -1) {
            gradleProperties.splice(existingIndex, 1);
        }
        if (!props) {
            return config;
        }
        gradleProperties.push({
            type: "property",
            key: "RNAS_PINNING_CONFIG",
            value: JSON.stringify(props).replaceAll('"', '\\\\"'),
        });
        return config;
    });
    return config;
};
exports.default = withSSLPinning;
